package org.bulatnig;

import javax.naming.InitialContext;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Properties;

/**
 * Connect to Glassfish embedded JMS server through JNDI lookup.
 * This https://glassfish.dev.java.net/javaee5/ejb/EJB_FAQ.html guide used.
 *
 * @author Bulat Nigmatullin
 */
public final class Main {

    private static final String OBJECT_JNDI_NAME = "/jms/TestConnectionFactory";

    private Object simple() throws Exception {
        Object obj = new InitialContext().lookup(OBJECT_JNDI_NAME);
        return obj;
    }

    private Object complex() throws Exception {
        Properties props = new Properties();
        props.setProperty("java.naming.factory.initial", "com.sun.enterprise.naming.SerialInitContextFactory");
        props.setProperty("java.naming.factory.url.pkgs", "com.sun.enterprise.naming");
        props.setProperty("java.naming.factory.state", "com.sun.corba.ee.impl.presentation.rmi.JNDIStateFactoryImpl");
        // optional.  Defaults to localhost.  Only needed if web server is running
        // on a different host than the appserver
        props.setProperty("org.omg.CORBA.ORBInitialHost", "localhost");
        // optional.  Defaults to 3700.  Only needed if target orb port is not 3700.
        props.setProperty("org.omg.CORBA.ORBInitialPort", "3700");
        InitialContext ic = new InitialContext(props);
        Object obj = ic.lookup(OBJECT_JNDI_NAME);
        return obj;
    }

    private void printClassPath() throws Exception {
        ClassLoader sysClassLoader = ClassLoader.getSystemClassLoader();
        URL[] urls = ((URLClassLoader) sysClassLoader).getURLs();
        for (int i = 0; i < urls.length; i++)
            System.out.println(urls[i].getFile());
    }

    private void lookup() throws Exception {
        Object result = simple();
        System.out.println("Result: " + result);
    }

    public static void main(String[] args) throws Exception {
        Main main = new Main();
        main.lookup();
    }
}
